@@ -4,7 +4,7 @@ from Products.CMFCore.interfaces import ISiteRoot
 from getpaid.core.interfaces import keys
 from getpaid.verkkomaksut.interfaces import IVerkkomaksutProcessor, IVerkkomaksutOptions, IVerkkomaksutOrderInfo
 
-from urllib import urlencode#, urlopen
+from urllib import urlencode
 from urllib2 import urlopen, HTTPSHandler, Request
 import md5
 
@@ -27,7 +27,5 @@ class VerkkomaksutProcessor( object ):
         order_info = IVerkkomaksutOrderInfo(order)()
         data = urlencode(order_info)
         request = Request(action_url, data)
-#        HTTPSHandler().https_open(request)
-#        return keys.results_async
         f = urlopen(request)
         return self.request.response.redirect(f.geturl())
